package com.bull.cimero.pluginEditor.utils.propertyCombo;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.views.properties.PropertyDescriptor;

 /**
 * Descriptor for a property that has a value which should be edited
 * with a combo box cell editor.  This class provides a default
 * <code>ILabelProvider</code> that will render the label of the given
 * descriptor as the <code>String</code> found in the labels array at the
 * currently selected index.
 * The value of the property is a 0-based <code>Integer</code> index into
 * the labels array.
 * This class may be instantiated; it is not intended to be subclassed.
 * Example:
 * IPropertyDescriptor pd = new ComboBoxPropertyEditable(
 * 			"origin", "Origin", values);
 */
public class ComboBoxPropertyEditable extends PropertyDescriptor {

	    /** The labels to display in the combo box. */
	    private String[] labels;
	    /**The cell editor using by this component.*/
	    private ComboBoxCellEditorEditable editor = null;
	    /**The labels provider.*/
	    private ComboBoxLabelproviderEditable monLabel = null;

	    /**
	     * Creates an property descriptor with the given id,
	     * display name, and list
	     * of value labels to display in the combo box cell editor.
	     * @param id the id of the property
	     * @param displayName the name to display for the property
	     * @param labelsArray the labels to display in the combo box
	     */
	    public ComboBoxPropertyEditable(final Object id
	    		, final String displayName, final String[] labelsArray) {
	        super(id, displayName);
	        labels = labelsArray;
	    }

	    /**
	     * The <code>ComboBoxPropertyDescriptor</code> implementation of this
	     * <code>IPropertyDescriptor</code> method creates and returns a new
	     * <code>ComboBoxCellEditor</code>.
	     * The editor is configured with the current validator if there is one.
	     * @param parent : composite parent
	     * @return CellEditor : created editor
	     */
	    public final CellEditor createPropertyEditor(
	    					final Composite parent) {
	    	editor = new ComboBoxCellEditorEditable(parent, labels, this);
	        if (getValidator() != null) {
				editor.setValidator(getValidator());
			}
	        return editor;
	    }

	    /**
	     * The <code>ComboBoxPropertyDescriptor</code> implementation of this
	     * <code>IPropertyDescriptor</code> method returns the value set by
	     * the <code>setProvider</code> method or, if no value has been set
	     * it returns a <code>ComboBoxLabelProvider</code> created from the
	     * valuesArray of this <code>ComboBoxPropertyDescriptor</code>.
	     * @see #setLabelProvider
	     * @return ILabelProvider : wanted label
	     */
	    public final ILabelProvider getLabelProvider() {
	    	if (monLabel == null) {
	    		monLabel = new ComboBoxLabelproviderEditable(labels, this);
	    	}
	    	return monLabel;
	    }

		/**
		 * get the editor.
		 * @return the editor
		 */
		public final ComboBoxCellEditorEditable getEditor() {
			return editor;
		}

		/**
		 * get the labels.
		 * @return the labels
		 */
		public final String[] getLabels() {
			return labels;
		}

		/**
		 * get monLabel.
		 * @return the monLabel
		 */
		public final ComboBoxLabelproviderEditable getMonLabel() {
			return monLabel;
		}

		/**
		 * set the labels.
		 * @param labelsParam the labels to set
		 */
		public final void setLabels(final String[] labelsParam) {
			this.labels = labelsParam;
		}
}
